@@ -40,24 +40,15 @@ class DependenciesInstallError(Exception):
     pass
 
 
-@projection.command("update-lambda-dev")
-@click.option("--projection-dir", type=click.Path())
-@click.option(
-    "--dry-run",
-    is_flag=True,
-    default=False,
-    help="Enable dry run to verify inputs before actually submitting a custom projection to Gantry",
-)
-def update_lambda_dev(projection_dir, dry_run):
+def _update_dev_projection(
+    api_client: APIClient, projection: Dict, projection_dir: str, dry_run: bool
+):
     """
     For Gantry's developers only: Upload a custom projection directly from a folder
     that contains:
         1. config.yaml: contains custom projection definition
         2. function.zip: source code with all required dependencies to get invoked as a lambda
     """
-    gantry.init()
-    api_client = gantry.get_client().log_store._api_client
-
     click.secho("Parsing custom projection configs...", nl=False, fg="cyan")
     projection = _get_custom_projection_configs(projection_dir)
     click.secho("SUCCESS", fg="cyan")
@@ -117,6 +108,13 @@ def update(projection_dir, dry_run):
     projection = _get_custom_projection_configs(projection_dir)
     click.secho("SUCCESS", fg="cyan")
 
+    if _is_dev_projection(projection):
+        _update_dev_projection(api_client, projection, projection_dir, dry_run)
+    else:
+        _update_projection(api_client, projection, projection_dir, dry_run)
+
+
+def _update_projection(api_client: APIClient, projection: Dict, projection_dir: str, dry_run: bool):
     click.secho("Validate custom projection definition...", nl=False, fg="cyan")
     valid_config, err_msgs = _validate_custom_projection_configs(api_client, projection)
     if not valid_config:
@@ -363,5 +361,12 @@ def _get_build_logs(api_client: APIClient, task_id: str) -> Tuple[str, str]:
     return "ERROR", "Error getting task logs"
 
 
+def _is_dev_projection(projection: Dict) -> bool:
+    function_def = projection.get("function_definition")
+    if function_def and function_def.get("mode") == "lambda_dev":
+        return True
+    return False
+
+
 if __name__ == "__main__":
     projection()
