@@ -37,11 +37,18 @@ class GantryDatasetClient:
 
     def set_working_directory(self, working_dir: str) -> None:
         """
-        Set the  dataset client working directory. Your dataset will be pulled into this folder
-        when running ``pull()``.
+        Set the working directory for the dataset client. This is the directory where the local
+        copy of the dataset will be stored.
+
+        Example usage:
+
+        .. code-block:: python
+
+            import gantry.dataset as gdataset
+            gdataset.set_working_directory("your working directory")
 
         Args:
-            working_dir (str): absolute path of the directory used to store local copy of dataset.
+            working_dir (str): absolute path of the directory used to store local copy of datasets.
 
         Returns:
             ``None``
@@ -53,8 +60,22 @@ class GantryDatasetClient:
         self, name: str, bucket_name: Optional[str] = None, app_name: Optional[str] = None
     ) -> GantryDataset:
         """
-        Create a dataset in your organization with the provided name, optionally providing a
-        storing bucket if desired.
+        Create a dataset with the provided name. If ``app_name`` is provided, we will use the
+        application schema to set the dataset schema. ``bucket_name`` can be provided if you want
+        to store data in your own bucket, please contact Gantry support if you want to use
+        this feature. If not provided, we will use a gantry managed bucket.
+
+        Example usage:
+
+        .. code-block:: python
+
+            import gantry.dataset as gdataset
+            # Create an empty dataset with the name "dataset_name"
+            gdataset.create_dataset("dataset_name")
+            # Create a dataset with the name "dataset_name" and set the schema to the schema of the
+            # application "app_name"
+            gdataset.create_dataset("dataset_with_app", app_name="app_name")
+
 
         Args:
             name (str): dataset name
@@ -64,7 +85,7 @@ class GantryDatasetClient:
                 dataset schema if provided.
 
         Returns:
-            :class:`gantry.dataset.GantryDataset`: an object representing the crated dataset.
+            :class:`gantry.dataset.GantryDataset`: an object representing the created dataset.
         """
         data = {
             "name": name,
@@ -98,10 +119,19 @@ class GantryDatasetClient:
     @typechecked
     def get_dataset(self, name: str) -> GantryDataset:
         """
-        Query Gantry for a dataset object corresponding to the provided name.
+        Get a dataset object by name. If the dataset is marked as deleted, a warning will be
+        logged. If the dataset does not exist, a :class:`gantry.exceptions.DatasetNotFoundError`
+        will be raised.
+
+        Example usage:
+
+        .. code-block:: python
+
+            import gantry.dataset as gdataset
+            dataset = gdataset.get_dataset("dataset_name")
 
         Args:
-            name (str): the name of the dataset to be retrieved.
+            name (str): the name of the dataset.
 
         Returns:
             :class:`gantry.dataset.GantryDataset`: An object representing the dataset name.
@@ -129,8 +159,32 @@ class GantryDatasetClient:
     @typechecked
     def list_dataset_versions(self, dataset_name: str) -> List[Dict[str, Any]]:
         """
-        Provide a list of versions of this dataset, and metadata associated
-        with those versions.
+        List all versions of a dataset. Each dataset version is a snapshot of the dataset at a
+        particular point in time. The result will be sorted from latest to earliest.
+
+        Example usage:
+
+        .. code-block:: python
+
+            import gantry.dataset as gdataset
+            gdataset.list_dataset_versions("dataset_name")
+
+        Output example:
+
+        .. code-block:: text
+
+            [{'version_id': 'd6f42bd0-b7a9-4089-88fb-be7cee6d4a83',
+            'dataset': 'dataset_name',
+            'message': 'version info',
+            'created_at': 'Wed, 08 Feb 2023 22:02:02 GMT',
+            'created_by': 'db459d6d-c83b-496d-b659-e48bca971156',
+            'is_latest_version': True},
+            {'version_id': 'b787034a-798b-4bb3-a726-0e197ddb8aff',
+            'dataset': 'dataset_name',
+            'message': 'initial dataset commit',
+            'created_at': 'Wed, 08 Feb 2023 22:00:26 GMT',
+            'created_by': 'db459d6d-c83b-496d-b659-e48bca971156',
+            'is_latest_version': False}]
 
         Args:
             name (str): the name of the dataset.
@@ -145,10 +199,33 @@ class GantryDatasetClient:
     @typechecked
     def list_datasets(self, include_deleted: bool = False) -> List[Dict[str, Any]]:
         """
-        List datasets all datasets in the organizations' namespace.
+        List all datasets. If ``include_deleted`` is set to ``True``, deleted datasets will be
+        included in the result list.
+
+        Example usage:
+
+        .. code-block:: python
+
+            import gantry.dataset as gdataset
+            gdataset.list_datasets()
+
+        Output example:
+
+        .. code-block:: text
+
+            [{'name': 'dataset_0',
+            'dataset_id': '44e8dff0-1e4c-4484-843c-ca3c585d405d',
+            'created_at': 'Sun, 12 Feb 2023 00:08:12 GMT'},
+            {'name': 'dataset_1',
+            'dataset_id': '3adb66fa-9dc7-4a60-86b6-83389f567186',
+            'created_at': 'Sun, 12 Feb 2023 00:05:15 GMT'},
+            {'name': 'dataset_2',
+            'dataset_id': '0a5b5706-2060-4601-8c5c-22900f06d54a',
+            'created_at': 'Wed, 08 Feb 2023 22:00:26 GMT'},
 
         Args:
-            include_deleted (bool): include deleted datasets, defaults to ``False``.
+            include_deleted (bool): whether include deleted datasets in the result, defaults
+                to ``False``.
 
         Returns:
             ``List[Dict[str, Any]]``: List of dictionaries, each representing one
@@ -164,9 +241,18 @@ class GantryDatasetClient:
         return [self._prune_dataset_info(dataset_info) for dataset_info in res["data"]]
 
     @typechecked
-    def delete_dataset(self, name: str):
+    def delete_dataset(self, name: str) -> None:
         """
-        Delete the named dataset.
+        Mark the dataset as deleted. As for now this will only hide dataset from the list_datasets
+        API results, it will not delete the dataset data from the server, we will release the
+        hard deletion feature later.
+
+        Example usage:
+
+        .. code-block:: python
+
+            import gantry.dataset as gdataset
+            gdataset.delete_dataset("dataset_name")
 
         Args:
             name (str): the name of the dataset to be deleted.
