@@ -1,3 +1,4 @@
+import concurrent
 import contextlib
 import csv
 import functools
@@ -35,8 +36,11 @@ from gantry.exceptions import (
 )
 from gantry.query.core.dataframe import GantryDataFrame
 from gantry.utils import (
+    _download_file_to_IO,
+    _upload_file_from_IO,
     download_file_from_url,
     get_files_checksum,
+    get_s3_sha256_checksum,
     list_all_files,
     parse_s3_path,
     read_lines_from_url,
@@ -473,7 +477,7 @@ class GantryDataset:
                 "raw_data_query_parameters": {
                     "filters": filters,
                     "tags": tags,
-                    "include_join_id": False,
+                    "include_join_id": True,
                     "hidden_columns": None,
                     "start_time": start_time,
                     "end_time": end_time,
@@ -1034,27 +1038,85 @@ class GantryDataset:
         commit_msg: Optional[str],
         parent_commit_id: Optional[Union[uuid.UUID, str]],
     ):
+        # check if parent commit is out of date
         if parent_commit_id is not None:
             if str(parent_commit_id) != self._get_latest_commit()["id"]:
                 raise DatasetHeadOutOfDateException()
 
         if commit_msg is None:
             commit_msg = f"Uploaded {filename} to dataset"
+        commit_id = uuid.uuid4()
 
-        data = {
-            "commit_msg": commit_msg,
-        }
-        files = {
-            "file": (filename, file),
-        }
+        # get sha256 checksum
+        try:
+            file.seek(0)
+            file_sha256 = get_s3_sha256_checksum(file.read())
+        except TypeError:
+            file.seek(0)
+            file_sha256 = get_s3_sha256_checksum(bytes(file.read(), encoding="utf-8"))
+        file.seek(0)
 
-        resp = self._api_client.request(
-            "POST",
-            f"/api/v1/datasets/{self._dataset_id}/file",
-            files=files,
-            data=data,
-            raise_for_status=True,
+        # get file directory
+        file_dir = constants.ARTIFACTS
+        if len(filename) > 4 and filename[-4:] == constants.CSV_SUFFIX:
+            file_dir = constants.TABULAR_MANIFESTS
+
+        # get put urls:
+        upload_file_info = DatasetFileInfo(
+            file_name=f"{file_dir}/{filename}",
+            url=self._get_s3_url(f"{file_dir}/{filename}", commit_id),
+            sha256=file_sha256,
         )
+        manifest_file_info = DatasetFileInfo(
+            file_name=constants.DATASET_MANIFEST_FILE,
+            url=self._get_s3_url(constants.DATASET_MANIFEST_FILE),
+        )
+        urls = self._generate_put_presign_url([upload_file_info, manifest_file_info])
+
+        # upload added file to s3
+        upload_file_info.version_id = _upload_file_from_IO(
+            urls[self._get_obj_key(upload_file_info.url)], file
+        )
+
+        # download manifest file
+        url = self._generate_get_presign_url([manifest_file_info])[
+            self._get_obj_key(manifest_file_info.url)
+        ]
+        manifest_file = io.BytesIO()
+        _download_file_to_IO(url, manifest_file)
+        # update manifest file
+        manifest_file.write(bytes(upload_file_info.to_jsonl(), encoding="utf-8"))
+        manifest_file.seek(0)
+        # upload new manifest file
+        version_id = _upload_file_from_IO(
+            urls[self._get_obj_key(manifest_file_info.url)], manifest_file
+        )
+
+        # create dataset commit
+        try:
+            resp = self._api_client.request(
+                "POST",
+                f"/api/v1/datasets/{self._dataset_id}/commits",
+                json={
+                    "message": commit_msg,
+                    "metadata_s3_file_version": version_id,
+                    "parent_commit_id": (
+                        self._get_current_commit()["id"]
+                        if parent_commit_id is None
+                        else parent_commit_id
+                    ),
+                    "commit_id": commit_id,
+                },
+                raise_for_status=True,
+            )
+        except GantryRequestException as e:
+            if (
+                e.status_code == 400
+                and 'Details: {"error":"Parent version out of date!","response":"error"}'
+                in e.args[0]
+            ):
+                raise DatasetHeadOutOfDateException
+            raise e
 
         commit_info = resp["data"]
         return self._prune_commit_info(commit_info)
@@ -1125,14 +1187,30 @@ class GantryDataset:
         Args:
             file_list (List[DatasetFileInfo]):
         """
+        if len(file_list) == 0:
+            logger.info("No files to download")
+            return
+        url_args = []
+        path_args = []
+        presigned_urls = {}
         for i in range(0, len(file_list), BATCH_SIZE):
-            batch = file_list[i : i + BATCH_SIZE]
-            presigned_urls = self._generate_get_presign_url(batch=batch)
+            presigned_urls.update(
+                self._generate_get_presign_url(batch=file_list[i : i + BATCH_SIZE])
+            )
+        for item in file_list:
+            local_path = Path(self._get_file_path(item.file_name))
+            presigned_url = presigned_urls[self._get_obj_key(item.url)]
+            path_args.append(local_path)
+            url_args.append(presigned_url)
 
-            for item in batch:
-                local_path = self._get_file_path(item.file_name)
-                presigned_url = presigned_urls[self._get_obj_key(item.url)]
-                download_file_from_url(presigned_url=presigned_url, local_path=Path(local_path))
+        with concurrent.futures.ThreadPoolExecutor(max_workers=BATCH_SIZE) as executor:
+            logger.info("Starting multipart dataset file download")
+            futures = [
+                executor.submit(download_file_from_url, url, path)
+                for url, path in zip(url_args, path_args)
+            ]
+            parts = [f.result() for f in concurrent.futures.as_completed(futures)]
+            logger.info(f"Multipart dataset file download completed: {parts}")
 
     def _generate_get_presign_url(self, batch: List[DatasetFileInfo], expiration: int = 3600):
         resp = self._api_client.request(
@@ -1154,34 +1232,57 @@ class GantryDataset:
 
     def _upload_files(self, file_list: List[DatasetFileInfo]):
         """
-        download file to the specific path
+        upload file to the specific path
 
         Args:
             file_list (List[DatasetFileInfo]):
         Returns:
             List[DatasetFileInfo]
         """
+        if len(file_list) == 0:
+            logger.info("No files to upload")
+            return file_list
+        url_args = []
+        path_args = []
+        presigned_urls = {}
         for i in range(0, len(file_list), BATCH_SIZE):
-            batch = file_list[i : i + BATCH_SIZE]
             resp = self._api_client.request(
                 "POST",
                 f"/api/v1/datasets/{self._dataset_id}/presign/putobject",
-                json={"obj_keys": [self._get_obj_key(f.url) for f in batch]},
+                json={
+                    "obj_keys": [self._get_obj_key(f.url) for f in file_list[i : i + BATCH_SIZE]]
+                },
                 raise_for_status=True,
             )
-            presigned_urls = resp["data"]
-
-            for item in batch:
-                local_path = self._get_file_path(item.file_name)
-                presigned_url = presigned_urls[self._get_obj_key(item.url)]
-                version_id = upload_file_to_url(
-                    presigned_url=presigned_url, local_path=Path(local_path)
-                )
-                item.version_id = version_id
-                logger.info(f"successfully upload: {item.file_name}")
-
+            presigned_urls.update(resp["data"])
+        for item in file_list:
+            url_args.append(presigned_urls[self._get_obj_key(item.url)])
+            path_args.append(Path(self._get_file_path(item.file_name)))
+        with concurrent.futures.ThreadPoolExecutor(max_workers=BATCH_SIZE) as executor:
+            logger.info("Starting multipart dataset file upload")
+            futures = [
+                executor.submit(GantryDataset._multipart_upload_helper, url, path, item)
+                for url, path, item in zip(url_args, path_args, file_list)
+            ]
+            parts = [f.result() for f in concurrent.futures.as_completed(futures)]
+            logger.info(f"Multipart dataset file upload completed: {parts}")
         return file_list
 
+    @staticmethod
+    def _multipart_upload_helper(url: str, path: Path, item: DatasetFileInfo):
+        version_id = upload_file_to_url(presigned_url=url, local_path=path)
+        item.version_id = version_id
+        return item.file_name
+
+    def _generate_put_presign_url(self, batch: List[DatasetFileInfo]):
+        resp = self._api_client.request(
+            "POST",
+            f"/api/v1/datasets/{self._dataset_id}/presign/putobject",
+            json={"obj_keys": [self._get_obj_key(f.url) for f in batch]},
+            raise_for_status=True,
+        )
+        return resp["data"]
+
     def _extract_feature_type(self) -> Dict[str, Any]:
         """
         Read feature type from dataset_config and convert them to huggingface feature type
