@@ -17,12 +17,15 @@ logger_obj = logging.getLogger(__name__)
 
 def _dataset_client_alias(f):
     doc = "Alias for :meth:`gantry.dataset.client.GantryDatasetClient.{}`".format(f.__name__)
+    signature = inspect.signature(getattr(GantryDatasetClient, f.__name__))
     orig_doc = inspect.getdoc(getattr(GantryDatasetClient, f.__name__))
 
     if orig_doc:
         doc += "\n\n{}".format(orig_doc)
+    signature = signature.replace(parameters=tuple(signature.parameters.values())[1:])
 
     f.__doc__ = doc
+    f.__signature__ = signature
 
     # This decorator also checks that the _CLIENT
     # has been initialized
