@@ -1,6 +1,6 @@
 import functools
 import warnings
-from typing import Dict, List
+from typing import Dict, List, Optional
 
 try:
     from typing import Literal
@@ -104,8 +104,8 @@ class GantryMetric(object):
         self,
         data_nodes: List[GantrySeries],
         stat: str,
-        num_points: int = None,
-        stat_kwargs: dict = None,
+        num_points: Optional[int] = None,
+        stat_kwargs: Optional[dict] = None,
     ) -> List[Dict]:
         if (num_points is not None) and (num_points < 1):
             raise ValueError(
