@@ -167,7 +167,11 @@ def _build_empty_df_with_schema(schema: Dict[str, str]) -> pd.DataFrame:
 
 
 def _build_batch_id_filter(batch_id: str) -> dict:
-    return {"feature_name": "batch_id", "string_query": batch_id, "is_reserved_field": True}
+    return {
+        "feature_name": "batch_id",
+        "string_query": batch_id,
+        "dtype": "reserved_field",
+    }
 
 
 def _get_application_batches(
