@@ -54,17 +54,3 @@ def commit_history():
             "parent_commit": None,
         },
     ]
-
-
-@pytest.fixture(scope="function")
-def add_file_commit():
-    return {
-        "created_at": "Tue, 05 Oct 2022 22:15:25 GMT",
-        "created_by": "fb459d6d-c83b-496d-b659-e48bca971156",
-        "dataset_id": DATASET_ID,
-        "id": "ab2e7242-3340-4edf-8366-90d4fce897ce",
-        "is_latest_commit": True,
-        "message": "add file test commit",
-        "metadata_s3_file_version": "QHHV3BI3euX_LbOiV5EjAouxHuX3ZBFh",
-        "parent_commit": "8ee0f6d5-c84c-473a-931a-5148b2e704d7",
-    }
