@@ -623,39 +623,91 @@ def setup_resp_for_sync(
         )
 
 
-def setup_resp_for_add_file(resp, commit_message, filename, file):
+def setup_resp_for_add_file(resp, commit_message, filename, parent_commit_id=None):
+    file_dir = "artifacts"
+    if len(filename) > 4 and filename[-4:] == ".csv":
+        file_dir = "tabular_manifests"
+
+    file_url = f"org_id/datasets/v1/{DATASET_NAME}/test-uuid-1/{file_dir}/{filename}"
+
+    # for uploading the added file and the manifest file
     resp.add(
         resp.POST,
-        f"{HOST}/api/v1/datasets/{DATASET_ID}/file",
+        f"{HOST}/api/v1/datasets/{DATASET_ID}/presign/putobject",
         json={
             "response": "ok",
             "data": {
-                "created_at": "Wed, 05 Oct 2022 05:42:13 GMT",
-                "created_by": "db459d6d-c83b-496d-b659-e48bca971156",
-                "dataset_id": DATASET_ID,
-                "id": "8ee0f6d5-c84c-473a-931a-5148b2e704d7",
-                "is_latest_commit": True,
-                "message": commit_message,
-                "metadata_s3_file_version": MANIFEST_VERSION_ID,
-                "parent_commit": "eb2e7242-3340-4edf-8366-90d4fce897ce",
+                file_url: f"{HOST}/fake_presigned_url_0",
+                MANIFEST_OBJ_KEY: f"{HOST}/fake_presigned_url_1",
             },
         },
         headers={"Content-Type": "application/json"},
+    )
+    # for downloading the manifest file
+    resp.add(
+        resp.POST,
+        f"{HOST}/api/v1/datasets/{DATASET_ID}/presign/getobject",
+        json={
+            "response": "ok",
+            "data": {
+                MANIFEST_OBJ_KEY: f"{HOST}/fake_presigned_url_2",
+            },
+        },
+        headers={"Content-Type": "application/json"},
+    )
+
+    # fake presigned urls for downloading/uploading files
+    resp.add(
+        resp.PUT,
+        f"{HOST}/fake_presigned_url_0",
+        json={"response": "ok"},
+        headers={"x-amz-version-id": "fake_version_id"},
+    )
+    resp.add(
+        resp.PUT,
+        f"{HOST}/fake_presigned_url_1",
+        json={"response": "ok"},
+        headers={"x-amz-version-id": MANIFEST_VERSION_ID},
+    )
+    resp.add(
+        resp.GET,
+        f"{HOST}/fake_presigned_url_2",
+        body="test-string",
+    )
+
+    # for the actual commit creation request
+    resp.add(
+        resp.POST,
+        f"{HOST}/api/v1/datasets/{DATASET_ID}/commits",
+        json={
+            "data": {
+                "created_at": "Wed, 07 Oct 2022 06:11:02 GMT",
+                "created_by": "db459d6d-c83b-496d-b659-e48bca971156",
+                "dataset_id": DATASET_ID,
+                "id": "add-file-commit-id",
+                "is_latest_commit": True,
+                "message": commit_message,
+                "metadata_s3_file_version": MANIFEST_VERSION_ID,
+                "parent_commit": "8ee0f6d5-c84c-473a-931a-5148b2e704d7",
+            },
+        },
+        headers={"Content-Type": "application/json"},
+        status=200,
         match=[
-            matchers.multipart_matcher(
+            matchers.json_params_matcher(
                 {
-                    "file": (filename, file),
-                },
-                data={
-                    "commit_msg": commit_message,
-                },
+                    "message": commit_message,
+                    "metadata_s3_file_version": MANIFEST_VERSION_ID,
+                    "parent_commit_id": parent_commit_id or "4569ef0b-ff96-4110-a606-8d9d54fab382",
+                    "commit_id": "test-uuid-1",
+                }
             )
         ],
     )
 
 
-@patch("uuid.uuid4", lambda: "test-uuid-1")
-def test_create_commit(datadir, gantry_dataset_obj, commit_history):
+@patch("uuid.uuid4", return_value="test-uuid-1")
+def test_create_commit(mock_uuid, datadir, gantry_dataset_obj, commit_history):
     """
     Test create commit succeed
     """
@@ -680,8 +732,8 @@ def test_create_commit(datadir, gantry_dataset_obj, commit_history):
             assert json.load(f) == commit_history[0]  # verify HEAD has been updated
 
 
-@patch("uuid.uuid4", lambda: "test-uuid-1")
-def test_create_commit_failure(datadir, gantry_dataset_obj, commit_history):
+@patch("uuid.uuid4", return_value="test-uuid-1")
+def test_create_commit_failure(mock_uuid, datadir, gantry_dataset_obj, commit_history):
     """
     Test create commit failure, in this case we detect the head is not up to date and stop
     prematurely. This will happen during a race condition when another user committed a change and
@@ -937,6 +989,7 @@ def test_delete_dataset(gantry_dataset_obj):
         gantry_dataset_obj.delete()
 
 
+@patch("uuid.uuid4", return_value="test-uuid-1")
 @pytest.mark.parametrize(
     ("filename", "expected_filename"),
     [
@@ -947,7 +1000,7 @@ def test_delete_dataset(gantry_dataset_obj):
 @pytest.mark.parametrize("commit_message", [None, "test commit message"])
 @pytest.mark.parametrize("read_method", ["rt", "rb"])
 def test_add_file(
-    datadir, gantry_dataset_obj, filename, expected_filename, commit_message, read_method
+    mock_uuid, datadir, gantry_dataset_obj, filename, expected_filename, commit_message, read_method
 ):
     expected_commit_message = commit_message or f"Uploaded {expected_filename} to dataset"
 
@@ -957,7 +1010,6 @@ def test_add_file(
             resp,
             expected_commit_message,
             expected_filename,
-            open(datadir / "test_file.txt", read_method),
         )
 
         gantry_dataset_obj.push_file(
@@ -965,6 +1017,7 @@ def test_add_file(
         )
 
 
+@patch("uuid.uuid4", return_value="test-uuid-1")
 @pytest.mark.parametrize(
     ("real_filename", "provided_filename", "expected_filename"),
     [
@@ -975,7 +1028,12 @@ def test_add_file(
 )
 @pytest.mark.parametrize("commit_message", [None, "test commit message"])
 def test_add_tabular_file(
-    gantry_dataset_obj, real_filename, provided_filename, expected_filename, commit_message
+    mock_uuid,
+    gantry_dataset_obj,
+    real_filename,
+    provided_filename,
+    expected_filename,
+    commit_message,
 ):
     expected_commit_message = commit_message or f"Uploaded {expected_filename} to dataset"
 
@@ -990,7 +1048,6 @@ def test_add_tabular_file(
             resp,
             expected_commit_message,
             expected_filename,
-            csvfile,
         )
 
         csvfile.seek(0)
@@ -1016,6 +1073,7 @@ def test_add_tabular_file_bad_name(gantry_dataset_obj, real_filename, provided_f
             gantry_dataset_obj.push_tabular_file(csvfile, provided_filename)
 
 
+@patch("uuid.uuid4", return_value="test-uuid-1")
 @pytest.mark.parametrize(
     ("filename", "expected_filename"),
     [
@@ -1025,13 +1083,10 @@ def test_add_tabular_file_bad_name(gantry_dataset_obj, real_filename, provided_f
     ],
 )
 @pytest.mark.parametrize("commit_message", [None, "test commit message"])
-def test_add_dataframe(gantry_dataset_obj, filename, expected_filename, commit_message):
+def test_add_dataframe(mock_uuid, gantry_dataset_obj, filename, expected_filename, commit_message):
     expected_commit_message = commit_message or f"Uploaded {expected_filename} to dataset"
 
     df = pd.DataFrame({"A": [100, 101], "B": [200, 202]})
-    expected_file = StringIO()
-    df.to_csv(expected_file, index=False)
-    expected_file.seek(0)
 
     with responses.RequestsMock() as resp:
         setup_resp_for_deleted_check(resp)
@@ -1039,15 +1094,14 @@ def test_add_dataframe(gantry_dataset_obj, filename, expected_filename, commit_m
             resp,
             expected_commit_message,
             expected_filename,
-            expected_file,
         )
 
         gantry_dataset_obj.push_dataframe(df, filename, commit_message)
 
 
-@patch("uuid.uuid4", lambda: "uuid-uuid-uuid")
+@patch("uuid.uuid4", return_value="uuid-uuid-uuid")
 @pytest.mark.parametrize("filename", ["", "mock_filename"])
-def test_push_gantry_dataframe(gantry_dataset_obj, test_api_client, filename):
+def test_push_gantry_dataframe(mock_uuid, gantry_dataset_obj, test_api_client, filename):
     start_time = datetime.datetime.now()
     end_time = datetime.datetime.now()
     final_filename_prefixes = {
@@ -1095,7 +1149,7 @@ def test_push_gantry_dataframe(gantry_dataset_obj, test_api_client, filename):
                         "raw_data_query_parameters": {
                             "filters": gantrydf.filters,
                             "tags": gantrydf.tags,
-                            "include_join_id": False,
+                            "include_join_id": True,
                             "hidden_columns": None,
                             "start_time": str(start_time.isoformat()) + "Z",
                             "end_time": str(end_time.isoformat()) + "Z",
@@ -1299,15 +1353,17 @@ def test_add_item_bad_parent(gantry_dataset_obj, function, commit_history):
                 gantry_dataset_obj.push_dataframe(input, parent_version_id=parent_commit_id)
 
 
+@patch("uuid.uuid4", return_value="test-uuid-1")
 @pytest.mark.parametrize(("function"), [("push_file"), ("push_tabular_file"), ("push_dataframe")])
-def test_add_item_good_parent(gantry_dataset_obj, function, commit_history, add_file_commit):
+def test_add_item_good_parent(mock_uuid, gantry_dataset_obj, function, commit_history):
     parent_commit_id = commit_history[0]["id"]
+    filename = "test-file.csv"
 
     if function == "push_dataframe":
         input = pd.DataFrame()
     else:
         input = StringIO()
-        input.name = "file.csv"
+        input.name = filename
 
     with responses.RequestsMock() as resp:
         setup_resp_for_deleted_check(resp)
@@ -1320,27 +1376,23 @@ def test_add_item_good_parent(gantry_dataset_obj, function, commit_history, add_
             },
             headers={"Content-Type": "application/json"},
         )
-        resp.add(
-            resp.POST,
-            f"{HOST}/api/v1/datasets/{DATASET_ID}/file",
-            json={
-                "response": "ok",
-                "data": add_file_commit,
-            },
-            headers={"Content-Type": "application/json"},
+        setup_resp_for_add_file(
+            resp, f"Uploaded {filename} to dataset", filename, parent_commit_id=parent_commit_id
         )
 
         if function == "push_file":
-            new_commit = gantry_dataset_obj.push_file(input, parent_version_id=parent_commit_id)
+            new_commit = gantry_dataset_obj.push_file(
+                input, filename=filename, parent_version_id=parent_commit_id
+            )
         elif function == "push_tabular_file":
             new_commit = gantry_dataset_obj.push_tabular_file(
-                input, parent_version_id=parent_commit_id
+                input, filename=filename, parent_version_id=parent_commit_id
             )
         elif function == "push_dataframe":
             new_commit = gantry_dataset_obj.push_dataframe(
-                input, parent_version_id=parent_commit_id
+                input, filename=filename, parent_version_id=parent_commit_id
             )
 
-        new_commit["version_id"] == add_file_commit["id"]
-        new_commit["dataset"] == gantry_dataset_obj.dataset_name
-        new_commit["message"] == "add file test commit"
+        assert new_commit["version_id"] == "add-file-commit-id"
+        assert new_commit["dataset"] == gantry_dataset_obj.dataset_name
+        assert new_commit["message"] == f"Uploaded {filename} to dataset"
