@@ -4,8 +4,6 @@ import pytest
 from gantry.dataset import main
 from gantry.exceptions import ClientNotInitialized
 
-from .conftest import AWS_REGION, BUCKET_NAME, USER_EMAIL
-
 
 @pytest.mark.parametrize(
     ["method", "params"],
@@ -14,6 +12,7 @@ from .conftest import AWS_REGION, BUCKET_NAME, USER_EMAIL
         ("get_dataset", {"name": "dataset_name"}),
         ("list_dataset_versions", {"name": "dataset_name"}),
         ("list_datasets", {}),
+        ("delete_dataset", {"name": "dataset_name"}),
     ],
 )
 def test_uninit_client_main(method, params):
@@ -27,42 +26,39 @@ def test_uninit_client_main(method, params):
 
 @pytest.mark.parametrize("backend", ["", "/some/file", "tcp://other/protocol"])
 def test_global_init_error(backend):
-    """Test invalide backend"""
-    with pytest.raises(ValueError):
-        main.init(email=USER_EMAIL, backend=backend)
+    with mock.patch.dict("os.environ", {"GANTRY_LOGS_LOCATION": backend}):
+        with pytest.raises(ValueError):
+            main._init()
 
 
-@pytest.mark.parametrize("valid_backend", ["http", "https"])
-def test_no_api_key_provided(valid_backend):
+def test_no_api_key_provided():
     with mock.patch.dict("os.environ", {"GANTRY_API_KEY": ""}):
         with pytest.raises(ValueError):
-            main.init(email=USER_EMAIL, backend=valid_backend, api_key=None)
+            main._init(api_key=None)
 
 
 def test_init():
     """Test init"""
     passed_api_key = "some_key"
-    with mock.patch.dict("os.environ", {"GANTRY_API_KEY": passed_api_key}):
-        main.init(
-            email=USER_EMAIL,
-            backend="https://gantry.datasettest",
-            bucket_name=BUCKET_NAME,
-            aws_region=AWS_REGION,
-        )
-        assert main._DATASET._api_client._host == "https://gantry.datasettest"
+    with mock.patch.dict(
+        "os.environ",
+        {
+            "GANTRY_API_KEY": passed_api_key,
+            "GANTRY_LOGS_LOCATION": "https://foo/bar",
+            "GANTRY_DATASET_WORKING_DIR": "working_dir",
+        },
+    ):
+        main._init()
+        assert main._DATASET._api_client._host == "https://foo/bar"
         assert main._DATASET._api_client._api_key == passed_api_key
-        assert main._DATASET.email == USER_EMAIL
-        assert main._DATASET.bucket_name == BUCKET_NAME
-        assert main._DATASET.aws_region == AWS_REGION
+        assert main._DATASET.working_directory == "working_dir"
 
 
 def test_init_default():
     """Test init client with default values"""
-    main.init(email=USER_EMAIL, backend="https://foo/bar", api_key="ABCD1234")
-    assert main._DATASET._api_client._host == "https://foo/bar"
+    main._init(api_key="ABCD1234")
+    assert main._DATASET._api_client._host == "https://app.gantry.io"
     assert main._DATASET._api_client._api_key == "ABCD1234"
-    assert main._DATASET.email == USER_EMAIL
-    assert not main._DATASET.aws_region and not main._DATASET.bucket_name
 
 
 @pytest.mark.parametrize(
@@ -72,6 +68,8 @@ def test_init_default():
         ("get_dataset", {"name": "dataset_name"}),
         ("list_dataset_versions", {"name": "dataset_name"}),
         ("list_datasets", {}),
+        ("delete_dataset", {"name": "dataset_name"}),
+        ("set_working_directory", {"working_dir": "path"}),
     ],
 )
 def test_dataset_methods(method, params):
