@@ -4,7 +4,6 @@ from freezegun import freeze_time
 
 from gantry.exceptions import GantryLoggingDataTypeError
 from gantry.logger import event_builder
-from gantry.logger.constants import BatchType, UploadFileType
 
 from .conftest import CURRENT_TIME, CURRENT_TIME_STR, SOME_TIME, SOME_TIME_STR
 
@@ -45,25 +44,6 @@ def test_create_timestamp_idx(sort, timestamps, record_count, expected):
     assert list(event_builder._create_timestamp_idx(sort, timestamps, record_count)) == expected
 
 
-def test_build_data_link(datadir):
-    csv_file = datadir / "feedback.csv"
-    data_link = event_builder._build_data_link(
-        application="test_app",
-        version=0,
-        feedback_id=["feedback_id"],
-        feedbacks=["test_float", "test_int"],
-        filepath=str(csv_file),
-    )
-
-    assert data_link.application == "test_app"
-    assert data_link.version == "0"
-    assert data_link.file_type == UploadFileType.CSV_WITH_HEADERS
-    assert data_link.batch_type == BatchType.FEEDBACK
-    assert data_link.feedback_id["feedback_id"].ref == 0
-    assert data_link.feedback["test_float"].ref == 1
-    assert data_link.feedback["test_int"].ref == 2
-
-
 @freeze_time(CURRENT_TIME)
 @pytest.mark.parametrize("timestamp", [None, SOME_TIME])
 @pytest.mark.parametrize("feedback_version", [None, 5, "1.2.3"])
