@@ -12,6 +12,7 @@ from gantry.query.core.dataframe import GantryDataFrame, GantrySeries
 ORIGIN = "https://gantry-api:12345"
 START_TIME = datetime.datetime(2008, 9, 3, 20, 56, 35)
 END_TIME = datetime.datetime(2008, 9, 10, 23, 58, 23)
+SOME_DURATION = datetime.timedelta(days=7, hours=1, minutes=45, seconds=30)
 
 START_TIME_STR = START_TIME.isoformat()
 END_TIME_STR = END_TIME.isoformat()
@@ -115,7 +116,7 @@ def gantry_query_obj(api_client_obj):
 @pytest.fixture
 @mock.patch("gantry.query.core.dataframe.GantryDataFrame._build_series")
 def df_factory(mock_populate, api_client_obj):
-    def wrapper(filters):
+    def wrapper(filters, tags=None):
         with responses.RequestsMock() as rsps:
             rsps.add(
                 responses.GET,
@@ -131,6 +132,7 @@ def df_factory(mock_populate, api_client_obj):
                 start_time=START_TIME,
                 end_time=END_TIME,
                 filters=filters,
+                tags=tags,
             )
 
     return wrapper
@@ -192,13 +194,13 @@ def series_obj_factory(api_client_obj, query_info_obj):
 
 
 @pytest.fixture
-def series_obj_factory_with_filters(df_factory, api_client_obj, query_info_obj):
-    def wrapper(datatype, filters):
+def series_obj_factory_with_filters_and_tags(df_factory, api_client_obj, query_info_obj):
+    def wrapper(datatype, filters, tags):
         return dataframe.GantrySeries(
             name="series_name",
             datatype=datatype,
             series_type="prediction",
-            parent_dataframe=df_factory(filters=filters),
+            parent_dataframe=df_factory(filters=filters, tags=tags),
             id="abc123",
         )
 
