@@ -11,6 +11,7 @@ from freezegun import freeze_time
 from responses import matchers
 
 from gantry.query.core import queryframe
+from gantry.query.core.queryframe import _get_metadata
 
 from ..conftest import END_TIME, ORIGIN, START_TIME
 
@@ -528,6 +529,33 @@ def test_prepare_pandas_dataframe_empty(mock_dtypes, column, query_frame_obj):
     assert df.dtypes[2] == np.dtype("float64")
 
 
+def test_get_metadata(query_frame_obj):
+    application_name = "test name"
+    query_params = frozenset(
+        {
+            "start_time": START_TIME,
+            "end_time": END_TIME,
+            "version": "1.2.3",
+        }.items()
+    )
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            responses.GET,
+            "{}/api/v1/models/{}/schemas".format(ORIGIN, application_name),
+            json={
+                "response": "ok",
+                "data": {"some": "data"},
+            },
+        )
+
+        assert _get_metadata(query_frame_obj.api_client, application_name, query_params) == {
+            "some": "data"
+        }
+        assert _get_metadata(query_frame_obj.api_client, application_name, query_params) == {
+            "some": "data"
+        }  # @cached will protect us for the second request, no request mock needed
+
+
 def test_metadata(query_frame_obj):
     with responses.RequestsMock() as rsps:
         rsps.add(
