@@ -1,4 +1,5 @@
 import datetime
+import re
 
 import mock
 import pytest
@@ -6,7 +7,7 @@ import responses
 from responses import matchers
 
 from gantry.api_client import APIClient
-from gantry.exceptions import GantryException
+from gantry.exceptions import GantryException, GantryRequestException
 from gantry.query.client import COLOR_OPTIONS_FOR_VIEW, GantryQuery
 from gantry.query.core.dataframe import GantryDataFrame
 
@@ -244,7 +245,7 @@ def test_add_metric(gantry_query_obj):
     ],
 )
 @mock.patch("gantry.query.client.get_application_node_id")
-def test_create_view_invalid_params(
+def test_create_view_invalid_time_params(
     mock_get_app_node_id, gantry_query_obj, duration, start_time, end_time
 ):
     mock_get_app_node_id.return_value = "foobar12345"
@@ -259,6 +260,27 @@ def test_create_view_invalid_params(
         )
 
 
+@pytest.mark.parametrize(
+    ["app", "version", "error_msg"],
+    [
+        ("foo", "2", re.escape("Application foo[2] does not exist.")),
+        ("foobar", None, re.escape("Application foobar[latest] does not exist.")),
+    ],
+)
+@mock.patch("gantry.query.client.get_application_node_id")
+def test_create_view_inexistent_model(
+    mock_get_app_node_id, gantry_query_obj, app, version, error_msg
+):
+    mock_get_app_node_id.side_effect = GantryRequestException("staging.com", 100, "error msg")
+    with pytest.raises(ValueError, match=error_msg):
+        gantry_query_obj.create_view(
+            application=app,
+            name="bar",
+            version=version,
+            duration=datetime.timedelta(days=1),
+        )
+
+
 @pytest.mark.parametrize(
     ["kwargs", "expected_data"],
     [
